Chapter 3: Search Chaining
==========================

In chapter 3, we introduce non-linear search chaining, whereby model-fits are chained together to enable efficient and
robust modeling of large galaxy samples.

The chapter contains the following tutorials:

`Tutorial 1: Search Chaining <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_3_search_chaining/tutorial_1_search_chaining.ipynb>`_
- Breaking the modeling procedure into a chained sequence of model-fits.

`Tutorial 2: Prior Passing <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_3_search_chaining/tutorial_2_prior_passing.ipynb>`_
- How the results of earlier searches are passed to later searches.

`Tutorial 3: x2 Galaxies <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_3_search_chaining/tutorial_3_x2_galaxies.ipynb>`_
- Modeling a dataset with two galaxies using chained searches.